@@ -7,7 +7,7 @@ from django.utils.translation import ugettext_lazy as _
 from incuna_mail import send
 from rest_framework import generics, renderers, response, status, views
 from rest_framework.authtoken.views import ObtainAuthToken
-from rest_framework.permissions import AllowAny
+from rest_framework.permissions import AllowAny, IsAuthenticated
 
 from . import serializers, permissions
 
@@ -76,7 +76,7 @@ class PasswordResetEmailView(views.APIView):
         )
 
 
-class OneTimeUseAPIMixin:
+class OneTimeUseAPIMixin(object):
     def dispatch(self, request, *args, **kwargs):
         uidb64 = kwargs['uidb64']
         uid = urlsafe_base64_decode(force_text(uidb64))
@@ -90,7 +90,7 @@ class OneTimeUseAPIMixin:
         if not default_token_generator.check_token(self.user, token):
             return response.Response(status=status.HTTP_404_NOT_FOUND)
 
-        return super().dispatch(request, *args, **kwargs)
+        return super(OneTimeUseAPIMixin, self).dispatch(request, *args, **kwargs)
 
 
 class PasswordResetView(OneTimeUseAPIMixin, generics.UpdateAPIView):
@@ -104,6 +104,7 @@ class PasswordResetView(OneTimeUseAPIMixin, generics.UpdateAPIView):
 
 class PasswordChangeView(generics.UpdateAPIView):
     model = User
+    permission_classes = (IsAuthenticated,)
     serializer_class = serializers.PasswordChangeSerializer
 
     def get_object(self):
@@ -125,6 +126,7 @@ class VerifyAccountView(OneTimeUseAPIMixin, views.APIView):
 
 class ProfileDetailView(generics.RetrieveUpdateAPIView):
     model = User
+    permission_classes = (IsAuthenticated,)
     serializer_class = serializers.ProfileSerializer
 
     def get_object(self):
